@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::CheckExtraTests;
 # ABSTRACT: check xt tests before release
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 # Dependencies
 use Dist::Zilla 4.3 ();
@@ -55,11 +55,13 @@ sub before_release {
         die "no BuildRunner plugins specified" unless @builders;
         $_->build for @builders;
 
+        my $jobs = $self->can('default_jobs') ? $self->default_jobs : 1;
+
         require App::Prove;
         App::Prove->VERSION('3.00');
 
         my $app = App::Prove->new;
-        $app->process_args(qw/-r -b xt/);
+        $app->process_args( '-j', $jobs, qw/-r -b xt/ );
         $app->run or $self->log_fatal("Fatal errors in xt tests");
     }
 
@@ -85,7 +87,7 @@ Dist::Zilla::Plugin::CheckExtraTests - check xt tests before release
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
