@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::RunExtraTests;
 # ABSTRACT: support running xt tests via dzil test
-our $VERSION = '0.018'; # VERSION
+our $VERSION = '0.019'; # VERSION
 
 # Dependencies
 use Dist::Zilla 4.3 ();
@@ -34,11 +34,13 @@ sub test {
         die "no blib; failed to build properly?" unless -d 'blib';
     }
 
+    my $jobs = $self->can('default_jobs') ? $self->default_jobs : 1;
+
     require App::Prove;
     App::Prove->VERSION('3.00');
 
     my $app = App::Prove->new;
-    $app->process_args( qw/-r -b/, @dirs );
+    $app->process_args( '-j', $jobs, qw/-r -b/, @dirs );
     $app->run or $self->log_fatal("Fatal errors in xt tests");
     return;
 }
@@ -59,7 +61,7 @@ Dist::Zilla::Plugin::RunExtraTests - support running xt tests via dzil test
 
 =head1 VERSION
 
-version 0.018
+version 0.019
 
 =head1 SYNOPSIS
 
